@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -28,8 +28,8 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "camel-url-scanner.h"
 #include "camel-mime-filter-tohtml.h"
+#include "camel-url-scanner.h"
 #include "camel-utf8.h"
 
 /**
@@ -60,8 +60,10 @@ static struct {
 	{ CONVERT_WEB_URLS, { "nntp://",   "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "telnet://", "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "webcal://", "",        camel_url_web_start,      camel_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "callto://", "",        camel_url_web_start,      camel_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "h323://",   "",        camel_url_web_start,      camel_url_web_end      } },
+	{ CONVERT_WEB_URLS, { "mailto:",   "",        camel_url_web_start,      camel_url_web_end      } },
+	{ CONVERT_WEB_URLS, { "callto:",   "",        camel_url_web_start,      camel_url_web_end      } },
+	{ CONVERT_WEB_URLS, { "h323:",     "",        camel_url_web_start,      camel_url_web_end      } },
+	{ CONVERT_WEB_URLS, { "sip:",      "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "www.",      "http://", camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "ftp.",      "ftp://",  camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_ADDRSPEC, { "@",         "mailto:", camel_url_addrspec_start, camel_url_addrspec_end } },
@@ -80,7 +82,7 @@ CamelType
 camel_mime_filter_tohtml_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (),
 					    "CamelMimeFilterToHTML",
@@ -91,7 +93,7 @@ camel_mime_filter_tohtml_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_tohtml_init,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_tohtml_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -99,7 +101,7 @@ static void
 camel_mime_filter_tohtml_finalize (CamelObject *obj)
 {
 	CamelMimeFilterToHTML *filter = (CamelMimeFilterToHTML *) obj;
-	
+
 	camel_url_scanner_free (filter->scanner);
 }
 
@@ -107,7 +109,7 @@ static void
 camel_mime_filter_tohtml_init (CamelMimeFilterToHTML *filter)
 {
 	filter->scanner = camel_url_scanner_new ();
-	
+
 	filter->flags = 0;
 	filter->colour = 0;
 	filter->column = 0;
@@ -119,16 +121,16 @@ static char *
 check_size (CamelMimeFilter *filter, char *outptr, char **outend, size_t len)
 {
 	size_t offset;
-	
+
 	if (*outend - outptr >= len)
 		return outptr;
-	
+
 	offset = outptr - filter->outbuf;
-	
+
 	camel_mime_filter_set_size (filter, filter->outsize + len, TRUE);
-	
+
 	*outend = filter->outbuf + filter->outsize;
-	
+
 	return filter->outbuf + offset;
 }
 
@@ -137,41 +139,41 @@ citation_depth (const char *in)
 {
 	register const char *inptr = in;
 	int depth = 1;
-	
+
 	if (*inptr++ != '>')
 		return 0;
-	
+
 #if FOOLISHLY_UNMUNGE_FROM
 	/* check that it isn't an escaped From line */
 	if (!strncmp (inptr, "From", 4))
 		return 0;
 #endif
-	
+
 	while (*inptr != '\n') {
 		if (*inptr == ' ')
 			inptr++;
-		
+
 		if (*inptr++ != '>')
 			break;
-		
+
 		depth++;
 	}
-	
+
 	return depth;
 }
 
 static char *
-writeln (CamelMimeFilter *filter, const char *in, const char *inend, char *outptr, char **outend)
+writeln (CamelMimeFilter *filter, const unsigned char *in, const unsigned char *inend, char *outptr, char **outend)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	const char *inptr = in;
-	
+	const unsigned char *inptr = in;
+
 	while (inptr < inend) {
 		guint32 u;
-		
+
 		outptr = check_size (filter, outptr, outend, 16);
-		
-		u = camel_utf8_getc_limit ((const unsigned char **) &inptr, (const unsigned char *) inend);
+
+		u = camel_utf8_getc_limit (&inptr, inend);
 		switch (u) {
 		case 0xffff:
 			g_warning("Truncated utf8 buffer");
@@ -204,7 +206,7 @@ writeln (CamelMimeFilter *filter, const char *in, const char *inend, char *outpt
 			/* otherwise, FALL THROUGH */
 		case ' ':
 			if (html->flags & CAMEL_MIME_FILTER_TOHTML_CONVERT_SPACES
-			    && ((inptr == (in + 1) || *inptr == ' ' || *inptr == '\t'))) {
+			    && ((inptr == (in + 1) || (inptr < inend && (*inptr == ' ' || *inptr == '\t'))))) {
 				outptr = g_stpcpy (outptr, "&nbsp;");
 				html->column++;
 				break;
@@ -223,7 +225,7 @@ writeln (CamelMimeFilter *filter, const char *in, const char *inend, char *outpt
 			break;
 		}
 	}
-	
+
 	return outptr;
 }
 
@@ -256,14 +258,14 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 
 		return;
 	}
-	
+
 	camel_mime_filter_set_size (filter, inlen * 2 + 6, FALSE);
-	
+
 	inptr = in;
 	inend = in + inlen;
 	outptr = filter->outbuf;
 	outend = filter->outbuf + filter->outsize;
-	
+
 	if (html->flags & CAMEL_MIME_FILTER_TOHTML_PRE && !html->pre_open) {
 		outptr = g_stpcpy (outptr, "<pre>");
 		html->pre_open = TRUE;
@@ -279,11 +281,11 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 
 		html->column = 0;
 		depth = 0;
-		
+
 		if (html->flags & CAMEL_MIME_FILTER_TOHTML_MARK_CITATION) {
 			if ((depth = citation_depth (start)) > 0) {
 				/* FIXME: we could easily support multiple colour depths here */
-				
+
 				outptr = check_size (filter, outptr, &outend, 25);
 				outptr += sprintf(outptr, "<font color=\"#%06x\">", (html->colour & 0xffffff));
 			}
@@ -298,76 +300,76 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			outptr = g_stpcpy (outptr, "&gt; ");
 			html->column += 2;
 		}
-		
+
 #define CONVERT_URLS (CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS | CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES)
 		if (html->flags & CONVERT_URLS) {
 			size_t matchlen, buflen, len;
 			urlmatch_t match;
-			
+
 			len = inptr - start;
-			
+
 			do {
 				if (camel_url_scanner_scan (html->scanner, start, len, &match)) {
 					/* write out anything before the first regex match */
-					outptr = writeln (filter, start, start + match.um_so,
+					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + match.um_so,
 							  outptr, &outend);
-					
+
 					start += match.um_so;
 					len -= match.um_so;
-					
+
 					matchlen = match.um_eo - match.um_so;
-					
+
 					buflen = 20 + strlen (match.prefix) + matchlen + matchlen;
 					outptr = check_size (filter, outptr, &outend, buflen);
-					
+
 					/* write out the href tag */
 					outptr = g_stpcpy (outptr, "<a href=\"");
 					outptr = g_stpcpy (outptr, match.prefix);
 					memcpy (outptr, start, matchlen);
 					outptr += matchlen;
 					outptr = g_stpcpy (outptr, "\">");
-					
+
 					/* now write the matched string */
 					memcpy (outptr, start, matchlen);
 					html->column += matchlen;
 					outptr += matchlen;
 					start += matchlen;
 					len -= matchlen;
-					
+
 					/* close the href tag */
 					outptr = g_stpcpy (outptr, "</a>");
 				} else {
 					/* nothing matched so write out the remainder of this line buffer */
-					outptr = writeln (filter, start, start + len, outptr, &outend);
+					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + len, outptr, &outend);
 					break;
 				}
 			} while (len > 0);
 		} else {
-			outptr = writeln (filter, start, inptr, outptr, &outend);
+			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inptr, outptr, &outend);
 		}
-		
+
 		if ((html->flags & CAMEL_MIME_FILTER_TOHTML_MARK_CITATION) && depth > 0) {
 			outptr = check_size (filter, outptr, &outend, 8);
 			outptr = g_stpcpy (outptr, "</font>");
 		}
-		
+
 		if (inptr < inend) {
 			if (html->flags & CAMEL_MIME_FILTER_TOHTML_CONVERT_NL) {
 				outptr = check_size (filter, outptr, &outend, 5);
 				outptr = g_stpcpy (outptr, "<br>");
 			}
-			
+
 			*outptr++ = '\n';
 		}
-		
+
 		start = ++inptr;
 	} while (inptr < inend);
-	
+
 	if (flush) {
 		/* flush the rest of our input buffer */
 		if (start < inend)
-			outptr = writeln (filter, start, inend, outptr, &outend);
-		
+			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inend, outptr, &outend);
+
 		if (html->pre_open) {
 			/* close the pre-tag */
 			outptr = check_size (filter, outptr, &outend, 10);
@@ -377,7 +379,7 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 		/* backup */
 		camel_mime_filter_backup (filter, start, (unsigned) (inend - start));
 	}
-	
+
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
 	*outprespace = filter->outpre;
@@ -390,7 +392,7 @@ filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 	html_convert (filter, in, len, prespace, out, outlen, outprespace, FALSE);
 }
 
-static void 
+static void
 filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 		 char **out, size_t *outlen, size_t *outprespace)
 {
@@ -401,7 +403,7 @@ static void
 filter_reset (CamelMimeFilter *filter)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	
+
 	html->column = 0;
 	html->pre_open = FALSE;
 }
@@ -410,9 +412,9 @@ static void
 camel_mime_filter_tohtml_class_init (CamelMimeFilterToHTMLClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	camel_mime_filter_tohtml_parent = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
-	
+
 	filter_class->reset = filter_reset;
 	filter_class->filter = filter_filter;
 	filter_class->complete = filter_complete;
@@ -434,17 +436,17 @@ camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
 {
 	CamelMimeFilterToHTML *new;
 	int i;
-	
+
 	new = CAMEL_MIME_FILTER_TOHTML (camel_object_new (camel_mime_filter_tohtml_get_type ()));
-	
+
 	new->flags = flags;
 	new->colour = colour;
-	
+
 	for (i = 0; i < NUM_URL_PATTERNS; i++) {
 		if (patterns[i].mask & flags)
 			camel_url_scanner_add (new->scanner, &patterns[i].pattern);
 	}
-	
+
 	return CAMEL_MIME_FILTER (new);
 }
 
@@ -466,17 +468,17 @@ camel_text_to_html (const char *in, guint32 flags, guint32 colour)
 	CamelMimeFilter *filter;
 	size_t outlen, outpre;
 	char *outbuf;
-	
+
 	g_return_val_if_fail (in != NULL, NULL);
-	
+
 	filter = camel_mime_filter_tohtml_new (flags, colour);
-	
+
 	camel_mime_filter_complete (filter, (char *) in, strlen (in), 0,
 				    &outbuf, &outlen, &outpre);
-	
+
 	outbuf = g_strndup (outbuf, outlen);
-	
+
 	camel_object_unref (filter);
-	
+
 	return outbuf;
 }
