@@ -5,7 +5,7 @@
  *  Copyright 2001-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -26,18 +26,18 @@
 #endif
 
 #include <string.h>
-#include "camel-sasl.h"
-#include "camel-mime-utils.h"
-#include "camel-service.h"
 
+#include "camel-mime-utils.h"
 #include "camel-sasl-cram-md5.h"
 #include "camel-sasl-digest-md5.h"
 #include "camel-sasl-gssapi.h"
 #include "camel-sasl-kerberos4.h"
 #include "camel-sasl-login.h"
+#include "camel-sasl-ntlm.h"
 #include "camel-sasl-plain.h"
 #include "camel-sasl-popb4smtp.h"
-#include "camel-sasl-ntlm.h"
+#include "camel-sasl.h"
+#include "camel-service.h"
 
 
 #define w(x)
@@ -53,7 +53,7 @@ static void
 camel_sasl_class_init (CamelSaslClass *camel_sasl_class)
 {
 	parent_class = camel_type_get_global_classfuncs (CAMEL_OBJECT_TYPE);
-	
+
 	/* virtual method definition */
 	camel_sasl_class->challenge = sasl_challenge;
 }
@@ -70,7 +70,7 @@ CamelType
 camel_sasl_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (CAMEL_OBJECT_TYPE,
 					    "CamelSasl",
@@ -81,7 +81,7 @@ camel_sasl_get_type (void)
 					    NULL,
 					    (CamelObjectFinalizeFunc) camel_sasl_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -111,7 +111,7 @@ GByteArray *
 camel_sasl_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 {
 	g_return_val_if_fail (CAMEL_IS_SASL (sasl), NULL);
-	
+
 	return CS_CLASS (sasl)->challenge (sasl, token, ex);
 }
 
@@ -131,25 +131,27 @@ camel_sasl_challenge_base64 (CamelSasl *sasl, const char *token, CamelException
 {
 	GByteArray *token_binary, *ret_binary;
 	char *ret;
-	int len;
-	
+
 	g_return_val_if_fail (CAMEL_IS_SASL (sasl), NULL);
-	
-	if (token) {
+
+	if (token && *token) {
+		guchar *data;
+		gsize length = 0;
+
+		data = g_base64_decode (token, &length);
 		token_binary = g_byte_array_new ();
-		len = strlen (token);
-		g_byte_array_append (token_binary, token, len);
-		token_binary->len = camel_base64_decode_simple (token_binary->data, len);
+		g_byte_array_append (token_binary, data, length);
+		g_free (data);
 	} else
 		token_binary = NULL;
-	
+
 	ret_binary = camel_sasl_challenge (sasl, token_binary, ex);
 	if (token_binary)
 		g_byte_array_free (token_binary, TRUE);
 	if (!ret_binary)
 		return NULL;
-	
-	ret = camel_base64_encode_simple (ret_binary->data, ret_binary->len);
+
+	ret = g_base64_encode (ret_binary->data, ret_binary->len);
 	g_byte_array_free (ret_binary, TRUE);
 
 	return ret;
@@ -185,13 +187,13 @@ CamelSasl *
 camel_sasl_new (const char *service_name, const char *mechanism, CamelService *service)
 {
 	CamelSasl *sasl;
-	
+
 	g_return_val_if_fail (service_name != NULL, NULL);
 	g_return_val_if_fail (mechanism != NULL, NULL);
 	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
-	
+
 	/* We don't do ANONYMOUS here, because it's a little bit weird. */
-	
+
 	if (!strcmp (mechanism, "CRAM-MD5"))
 		sasl = (CamelSasl *) camel_object_new (CAMEL_SASL_CRAM_MD5_TYPE);
 	else if (!strcmp (mechanism, "DIGEST-MD5"))
@@ -219,7 +221,7 @@ camel_sasl_new (const char *service_name, const char *mechanism, CamelService *s
 	sasl->service_name = g_strdup (service_name);
 	sasl->service = service;
 	camel_object_ref (service);
-	
+
 	return sasl;
 }
 
@@ -234,7 +236,7 @@ GList *
 camel_sasl_authtype_list (gboolean include_plain)
 {
 	GList *types = NULL;
-	
+
 	types = g_list_prepend (types, &camel_sasl_cram_md5_authtype);
 	types = g_list_prepend (types, &camel_sasl_digest_md5_authtype);
 #ifdef HAVE_KRB5
@@ -246,7 +248,7 @@ camel_sasl_authtype_list (gboolean include_plain)
 	types = g_list_prepend (types, &camel_sasl_ntlm_authtype);
 	if (include_plain)
 		types = g_list_prepend (types, &camel_sasl_plain_authtype);
-	
+
 	return types;
 }
 
