@@ -19,39 +19,39 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
 #include <config.h>
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
 
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
-#include "camel/camel-session.h"
-#include "camel/camel-debug.h"
-#include "camel/camel-i18n.h"
-#include "camel/camel-types.h"
-#include "camel/camel-folder.h" 
-#include "camel/camel-private.h"
-#include "camel/camel-net-utils.h"
+#include "camel-debug.h"
+#include "camel-folder.h"
+#include "camel-net-utils.h"
+#include "camel-private.h"
+#include "camel-session.h"
+#include "camel-types.h"
 
+#include "camel-groupwise-folder.h"
+#include "camel-groupwise-store-summary.h"
 #include "camel-groupwise-store.h"
 #include "camel-groupwise-summary.h"
-#include "camel-groupwise-store-summary.h"
-#include "camel-groupwise-folder.h"
 #include "camel-groupwise-utils.h"
 
-#define d(x) 
+#define d(x)
 #define CURSOR_ITEM_LIMIT 100
 #define JUNK_ENABLE 1
 #define JUNK_PERSISTENCE 14
@@ -91,13 +91,13 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 	const char *property_value;
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
 	char *path = NULL;
-	
+
 	d("in groupwise store constrcut\n");
 
 	CAMEL_SERVICE_CLASS (parent_class)->construct (service, session, provider, url, ex);
 	if (camel_exception_is_set (ex))
 		return;
-	
+
 	if (!(url->host || url->user)) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID,
 				     _("Host or user not available in url"));
@@ -109,12 +109,12 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 	 * This is a dirty hack. But it *WORKS*
 	 */
 	groupwise_store->list_loaded = 3;
-	
+
 	/*storage path*/
 	priv->storage_path = camel_session_get_storage_path (session, service, ex);
 	if (!priv->storage_path)
 		return;
-	
+
 	/*store summary*/
 	path = g_alloca (strlen (priv->storage_path) + 32);
 	sprintf (path, "%s/.summary", priv->storage_path);
@@ -122,7 +122,7 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 	camel_store_summary_set_filename ((CamelStoreSummary *)groupwise_store->summary, path);
 	camel_store_summary_touch ((CamelStoreSummary *)groupwise_store->summary);
 	camel_store_summary_load ((CamelStoreSummary *) groupwise_store->summary);
-	
+
 	/*host and user*/
 	priv->server_name = g_strdup (url->host);
 	priv->user = g_strdup (url->user);
@@ -142,10 +142,10 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 		priv->port = g_strdup (property_value);
 
 	/*filter*/
-	if (camel_url_get_param (url, "filter")) 
+	if (camel_url_get_param (url, "filter"))
 		store->flags |= CAMEL_STORE_FILTER_INBOX;
-	
-	/*Hash Table*/	
+
+	/*Hash Table*/
 	priv->id_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	priv->name_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	priv->parent_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
@@ -182,13 +182,12 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 	gboolean authenticated = FALSE;
 	char *uri;
 
-	CAMEL_SERVICE_ASSERT_LOCKED (groupwise_store, connect_lock);
-	if (priv->use_ssl && !g_str_equal (priv->use_ssl, "never")) 
+	if (priv->use_ssl && !g_str_equal (priv->use_ssl, "never"))
 		uri = g_strconcat ("https://", priv->server_name, ":", priv->port, "/soap", NULL);
-	else 
+	else
 		uri = g_strconcat ("http://", priv->server_name, ":", priv->port, "/soap", NULL);
 	service->url->passwd = NULL;
-	
+
 
 	while (!authenticated) {
 		if (errbuf) {
@@ -197,11 +196,11 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 			g_free (service->url->passwd);
 			service->url->passwd = NULL;
 		}
-		
-	
+
+
 		if (!service->url->passwd && !(store->flags & CAMEL_STORE_PROXY)) {
 			char *prompt;
-			
+
 			prompt = g_strdup_printf (_("%sPlease enter the GroupWise "
 						    "password for %s@%s"),
 						  errbuf ? errbuf : "",
@@ -213,14 +212,14 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 			g_free (prompt);
 			g_free (errbuf);
 			errbuf = NULL;
-			
+
 			if (!service->url->passwd) {
 				camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL,
 						     _("You did not enter a password."));
 				return FALSE;
 			}
 		}
-		
+
 		priv->cnc = e_gw_connection_new (uri, priv->user, service->url->passwd);
 		if (!E_IS_GW_CONNECTION(priv->cnc) && priv->use_ssl && g_str_equal (priv->use_ssl, "when-possible")) {
 			char *http_uri = g_strconcat ("http://", uri + 8, NULL);
@@ -230,13 +229,13 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 		if (!E_IS_GW_CONNECTION(priv->cnc)) {
 			errbuf = g_strdup_printf (_("Unable to authenticate "
 					    "to GroupWise server. "));
-						  
+
 			camel_exception_clear (ex);
-		} else 
+		} else
 			authenticated = TRUE;
-		
+
 	}
-	
+
 	return TRUE;
 }
 
@@ -273,8 +272,8 @@ groupwise_connect (CamelService *service, CamelException *ex)
 	CamelSession *session = service->session;
 
 	d("in groupwise store connect\n");
-	
-/*	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL || 
+
+/*	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL ||
 	     (service->status == CAMEL_SERVICE_DISCONNECTED))
 		return FALSE; */
 	if (service->status == CAMEL_SERVICE_DISCONNECTED)
@@ -286,26 +285,26 @@ groupwise_connect (CamelService *service, CamelException *ex)
 		camel_service_construct (service, service->session, service->provider, service->url, ex);
 	}
 
-	CAMEL_SERVICE_LOCK (service, connect_lock);
-	
+	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
+
 	if (priv->cnc) {
-		CAMEL_SERVICE_UNLOCK (service, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 		return TRUE;
 	}
 
 	if (!check_for_connection (service, ex) || !groupwise_auth_loop (service, ex)) {
-		CAMEL_SERVICE_UNLOCK (service, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 		camel_service_disconnect (service, TRUE, NULL);
 		return FALSE;
 	}
-	
-	
+
+
 	service->status = CAMEL_SERVICE_CONNECTED;
 	((CamelOfflineStore *) store)->state = CAMEL_OFFLINE_STORE_NETWORK_AVAIL;
 
 	if (!e_gw_connection_get_version (priv->cnc)) {
-		camel_session_alert_user(session, 
-				CAMEL_SESSION_ALERT_WARNING, 
+		camel_session_alert_user(session,
+				CAMEL_SESSION_ALERT_WARNING,
 				_("Some features may not work correctly with your current server version"),
 				FALSE);
 
@@ -316,12 +315,12 @@ groupwise_connect (CamelService *service, CamelException *ex)
 
 	if (camel_store_summary_count ((CamelStoreSummary *)store->summary) == 0) {
 		/*Settting the refresh stamp to the current time*/
-		store->refresh_stamp = time (0);
+		store->refresh_stamp = time (NULL);
 	}
 
 	camel_store_summary_save ((CamelStoreSummary *) store->summary);
 
-	CAMEL_SERVICE_UNLOCK (service, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 	if (E_IS_GW_CONNECTION (priv->cnc)) {
 		return TRUE;
 	}
@@ -329,18 +328,19 @@ groupwise_connect (CamelService *service, CamelException *ex)
 	return FALSE;
 
 }
+#if 0
 static void
 groupwise_disconnect_cleanup (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (service);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
-	
+
 	g_print ("camel_groupwise_store_finalize\n");
 	if (groupwise_store->summary) {
 		camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		camel_object_unref (groupwise_store->summary);
 	}
-	
+
 	if (priv) {
 		if (priv->user) {
 			g_free (priv->user);
@@ -362,13 +362,13 @@ groupwise_disconnect_cleanup (CamelService *service, gboolean clean, CamelExcept
 			g_free (priv->base_url);
 			priv->base_url = NULL;
 		}
-		
+
 		if (priv->storage_path)
 			g_free(priv->storage_path);
 
 		if(groupwise_store->root_container)
 			g_free (groupwise_store->root_container);
-		
+
 		if (priv->id_hash)
 			g_hash_table_destroy (priv->id_hash);
 
@@ -382,21 +382,22 @@ groupwise_disconnect_cleanup (CamelService *service, gboolean clean, CamelExcept
 		groupwise_store->priv = NULL;
 	}
 }
+#endif
 
 static gboolean
 groupwise_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (service);
-	
+
 	if (clean) {
-		CAMEL_SERVICE_LOCK (groupwise_store, connect_lock);
+		CAMEL_SERVICE_REC_LOCK (groupwise_store, connect_lock);
 		if (groupwise_store->priv && groupwise_store->priv->cnc) {
 			g_object_unref (groupwise_store->priv->cnc);
 			groupwise_store->priv->cnc = NULL;
 		}
-		CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 	}
-	
+
 	//groupwise_disconnect_cleanup (service, clean, ex);
 	return TRUE;
 }
@@ -405,7 +406,7 @@ static  GList*
 groupwise_store_query_auth_types (CamelService *service, CamelException *ex)
 {
 	GList *auth_types = NULL;
-	
+
 	d("in query auth types\n");
 	auth_types = g_list_prepend (auth_types,  &camel_groupwise_password_authtype);
 	return auth_types;
@@ -434,19 +435,19 @@ groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const char *parent_na
 	CamelFolderInfo *fi;
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 
-	fi = g_malloc0(sizeof(*fi));
-	
+	fi = camel_folder_info_new();
+
 	fi->unread = -1;
 	fi->total = -1;
 
 	if (parent_name) {
-		if (strlen(parent_name) > 0) 
+		if (strlen(parent_name) > 0)
 			fi->full_name = g_strconcat(parent_name, "/", folder_name, NULL);
 		else
 			fi->full_name = g_strdup (folder_name);
-	} else 
+	} else
 		fi->full_name = g_strdup(folder_name);
- 
+
 	url = camel_url_new(priv->base_url,NULL);
 	g_free(url->path);
 	url->path = g_strdup_printf("/%s", fi->full_name);
@@ -466,7 +467,7 @@ groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const char *parent_na
 		fi->flags |= CAMEL_FOLDER_TYPE_TRASH;
 	else if (!strcmp (folder_name, "Junk Mail"))
 		fi->flags |= CAMEL_FOLDER_TYPE_JUNK;
-		
+
 	fi->name = g_strdup(name);
 	return fi;
 }
@@ -481,7 +482,7 @@ groupwise_forget_folder (CamelGroupwiseStore *gw_store, const char *folder_name,
 	CamelFolderInfo *fi;
 	const char *name;
 
-	
+
 	name = folder_name;
 
 	storage_path = g_strdup_printf ("%s/folders", priv->storage_path);
@@ -544,7 +545,7 @@ groupwise_get_folder_from_disk (CamelStore *store, const char *folder_name, guin
 	return folder;
 }
 
-static CamelFolder * 
+static CamelFolder *
 groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStore *gw_store = CAMEL_GROUPWISE_STORE (store);
@@ -555,11 +556,11 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	EGwConnectionStatus status;
 	GList *list = NULL;
 	gboolean done = FALSE, all_ok = TRUE;
-	const char *position = E_GW_CURSOR_POSITION_END; 
+	const char *position = E_GW_CURSOR_POSITION_END;
 	int count = 0, cursor, summary_count = 0;
 	CamelStoreInfo *si = NULL;
-	guint total;
-	
+	guint total = 0;
+
 	folder = groupwise_get_folder_from_disk (store, folder_name, flags, ex);
 	if (folder) {
 		camel_object_ref (folder);
@@ -568,13 +569,13 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 
 	camel_exception_clear (ex);
 
-	CAMEL_SERVICE_LOCK (gw_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
 
 	if (!camel_groupwise_store_connected ((CamelGroupwiseStore *)store, ex)) {
-		CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		return NULL;
 	}
-	
+
 	if (gw_store->current_folder) {
 		camel_object_unref (gw_store->current_folder);
 		gw_store->current_folder = NULL;
@@ -583,7 +584,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	if (!E_IS_GW_CONNECTION( priv->cnc)) {
 		if (!groupwise_connect (CAMEL_SERVICE(store), ex)) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE, _("Authentication failed"));
-			CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			return NULL;
 		}
 	}
@@ -596,14 +597,14 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	g_free(storage_path);
 	folder = camel_gw_folder_new (store, folder_name, folder_dir, ex);
 	if (!folder) {
-		CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
 		g_free (folder_dir);
 		g_free (container_id);
 		return NULL;
 	}
 	g_free (folder_dir);
-	
+
 	si = camel_store_summary_path ((CamelStoreSummary *)gw_store->summary, folder_name);
 	if (si) {
 		total = si->total;
@@ -616,12 +617,12 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	if(!summary_count || !summary->time_string) {
 		d(g_print ("\n\n** %s **: No summary as yet : using get cursor request\n\n", folder->name);)
 
-		status = e_gw_connection_create_cursor (priv->cnc, container_id, 
+		status = e_gw_connection_create_cursor (priv->cnc, container_id,
 				"peek id recipient attachments distribution subject status options priority startDate created delivered size hasAttachment",
 				NULL,
 				&cursor);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
-			CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			g_free (container_id);
 			return NULL;
 		}
@@ -630,14 +631,14 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		camel_folder_summary_clear (folder->summary);
 
 		while (!done) {
-			status = e_gw_connection_read_cursor (priv->cnc, container_id, 
-							      cursor, FALSE, 
+			status = e_gw_connection_read_cursor (priv->cnc, container_id,
+							      cursor, FALSE,
 							      CURSOR_ITEM_LIMIT, position, &list);
 			if (status != E_GW_CONNECTION_STATUS_OK) {
 				all_ok = FALSE;
 				break;
 				/*
-				CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+				CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 				e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 				//camel_folder_summary_clear (folder->summary);
 				camel_folder_summary_save (folder->summary);
@@ -647,13 +648,13 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 				g_free (container_id);
 				return NULL;*/
 			}
-			
+
 			count += g_list_length (list);
-		
+
 			if (total > 0)
 				camel_operation_progress (NULL, (100*count)/total);
 			gw_update_summary (folder, list,  ex);
-			
+
 			if (!list)
 				done = TRUE;
 			g_list_foreach (list, (GFunc)g_object_unref, NULL);
@@ -665,7 +666,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 
 		camel_operation_end (NULL);
-	} 
+	}
 	if (done && all_ok) {
 		if (summary->time_string)
 			g_free (summary->time_string);
@@ -678,12 +679,12 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	camel_object_ref (folder);
 
 	g_free (container_id);
-	CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 
 	return folder;
 }
 
-void 
+void
 gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
@@ -692,28 +693,28 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 	EGwConnectionStatus status;
 	GList *list = NULL;
 	gboolean done = FALSE;
-	const char *position = E_GW_CURSOR_POSITION_END; 
+	const char *position = E_GW_CURSOR_POSITION_END;
 	int count = 0, cursor, summary_count = 0;
 	CamelStoreInfo *si = NULL;
-	guint total;
-	
+	guint total = 0;
+
 	camel_exception_clear (ex);
 
-	CAMEL_SERVICE_LOCK (gw_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
 
 	if (!camel_groupwise_store_connected (gw_store, ex)) {
-		CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		return;
 	}
-	
+
 	if (!E_IS_GW_CONNECTION( priv->cnc)) {
 		if (!groupwise_connect (CAMEL_SERVICE((CamelStore*)gw_store), ex)) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE, _("Authentication failed"));
-			CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			return;
 		}
 	}
-	
+
 	container_id = 	g_strdup (g_hash_table_lookup (priv->name_hash, folder->full_name));
 
 	si = camel_store_summary_path ((CamelStoreSummary *)gw_store->summary, folder->name);
@@ -730,12 +731,12 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 	if(!summary_count || !summary->time_string) {
 		d(g_print ("\n\n** %s **: Summary missing???? Reloading summary....\n\n", folder->name);)
 
-		status = e_gw_connection_create_cursor (priv->cnc, container_id, 
-				"peek id recipient attachments distribution subject status options priority startDate created delivered size",
+		status = e_gw_connection_create_cursor (priv->cnc, container_id,
+				"peek id recipient attachments distribution subject status options priority startDate created delivered size hasAttachment",
 				NULL,
 				&cursor);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
-			CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			g_free (container_id);
 			return;
 		}
@@ -743,11 +744,11 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 		camel_operation_start (NULL, _("Fetching summary information for new messages in %s"), folder->name);
 
 		while (!done) {
-			status = e_gw_connection_read_cursor (priv->cnc, container_id, 
-							      cursor, FALSE, 
+			status = e_gw_connection_read_cursor (priv->cnc, container_id,
+							      cursor, FALSE,
 							      CURSOR_ITEM_LIMIT, position, &list);
 			if (status != E_GW_CONNECTION_STATUS_OK) {
-				CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+				CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 				e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 				camel_folder_summary_save (folder->summary);
 				camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
@@ -755,13 +756,13 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 				g_free (container_id);
 				return;
 			}
-			
+
 			count += g_list_length (list);
-		
+
 			if (total > 0)
 				camel_operation_progress (NULL, (100*count)/total);
 			gw_update_summary (folder, list,  ex);
-			
+
 			if (!list)
 				done = TRUE;
 			g_list_foreach (list, (GFunc)g_object_unref, NULL);
@@ -773,7 +774,7 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 		e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 
 		camel_operation_end (NULL);
-	} 
+	}
 
 	if (done) {
 		if (summary->time_string)
@@ -784,9 +785,9 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 	camel_folder_summary_save (folder->summary);
 
 	gw_store->current_folder = folder;
-	
+
 	g_free (container_id);
-	CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 	return;
 }
 
@@ -803,8 +804,8 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 	name = e_gw_container_get_name (container);
 	id = e_gw_container_get_id (container);
 	type = e_gw_container_get_container_type (container);
-		
-	fi = g_new0 (CamelFolderInfo, 1);
+
+	fi = camel_folder_info_new ();
 
 	if (type == E_GW_CONTAINER_TYPE_INBOX)
 		fi->flags |= CAMEL_FOLDER_TYPE_INBOX;
@@ -821,7 +822,7 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 		(type == E_GW_CONTAINER_TYPE_DRAFT) ||
 		(type == E_GW_CONTAINER_TYPE_CABINET) ||
 		(type == E_GW_CONTAINER_TYPE_JUNK) ||
-		(type == E_GW_CONTAINER_TYPE_TRASH) ) 
+		(type == E_GW_CONTAINER_TYPE_TRASH) )
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
 	/*
 	   parent_hash contains the "parent id <-> container id" combination. So we form
@@ -843,12 +844,12 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 			temp = g_hash_table_lookup (priv->id_hash, temp_parent );
 			if (temp == NULL) {
 				break;
-			}	
+			}
 			str = g_strconcat ( temp, "/", str, NULL);
 
 			temp_parent = g_hash_table_lookup (priv->parent_hash, temp_parent);
 
-		} 
+		}
 		fi->full_name = g_strdup (str);
 		fi->uri = g_strconcat (url, str, NULL);
 		g_free (str);
@@ -874,24 +875,14 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 	if (e_gw_container_get_is_shared_by_me (container))
 		fi->flags |= CAMEL_FOLDER_SHARED_BY_ME;
 
-	/*if (type == E_GW_CONTAINER_TYPE_INBOX) {
-		fi->total = -1;
-		fi->unread = -1;
-	} else	if (type == E_GW_CONTAINER_TYPE_TRASH) {*/
-			
-	if (type == E_GW_CONTAINER_TYPE_TRASH || type == E_GW_CONTAINER_TYPE_SENT) {
-		fi->total = e_gw_container_get_total_count (container);
-		fi->unread = 0; 
-		/* Done with a belief that user wont mark something as unread in Trash and Sent Items */
-	} else {
-		fi->total = e_gw_container_get_total_count (container);
-		fi->unread = e_gw_container_get_unread_count (container);
-	}
+	fi->total = e_gw_container_get_total_count (container);
+	fi->unread = e_gw_container_get_unread_count (container);
+
 	si->info.total = fi->total;
 	si->info.unread = fi->unread;
 	si->info.flags = fi->flags;
 	/*refresh info*/
-	if (store->current_folder 
+	if (store->current_folder
 	    && !strcmp (store->current_folder->full_name, fi->full_name)
 	    && type != E_GW_CONTAINER_TYPE_INBOX) {
 		CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS (store->current_folder))->refresh_info(store->current_folder, ex);
@@ -944,7 +935,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 		g_free ((char *)url);
 		url = temp_url;
 	}
-	
+
 	/*populate the hash table for finding the mapping from container id <-> folder name*/
 	for (;temp_list != NULL ; temp_list = g_list_next (temp_list) ) {
 		const char *name, *id, *parent;
@@ -958,7 +949,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 		}
 
 		/*id_hash returns the name for a given container id*/
-		g_hash_table_insert (priv->id_hash, g_strdup(id), g_strdup(name)); 
+		g_hash_table_insert (priv->id_hash, g_strdup(id), g_strdup(name));
 		/*parent_hash returns the parent container id, given an id*/
 		g_hash_table_insert (priv->parent_hash, g_strdup(id), g_strdup(parent));
 	}
@@ -968,7 +959,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 	for (;folder_list != NULL; folder_list = g_list_next (folder_list)) {
 		EGwContainerType type;
 		EGwContainer *container = E_GW_CONTAINER (folder_list->data);
-		
+
 		type = e_gw_container_get_container_type (container);
 
 		if (e_gw_container_is_root(container))
@@ -987,7 +978,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 			}
 		}
 	}
-	
+
 	g_free ((char *)url);
 	e_gw_connection_free_container_list (list);
 	count = camel_store_summary_count ((CamelStoreSummary *)store->summary);
@@ -1042,9 +1033,9 @@ groupwise_get_folder_info_offline (CamelStore *store, const char *top,
 	for (i=0;i<camel_store_summary_count((CamelStoreSummary *)groupwise_store->summary);i++) {
 		CamelStoreInfo *si = camel_store_summary_index((CamelStoreSummary *)groupwise_store->summary, i);
 
-		if (si == NULL) 
+		if (si == NULL)
 			continue;
-		
+
 		if ( !strcmp(name, camel_groupwise_store_info_full_name (groupwise_store->summary, si))
 		     || match_path (path, camel_groupwise_store_info_full_name (groupwise_store->summary, si))) {
 			fi = groupwise_build_folder_info(groupwise_store, NULL, camel_store_info_path((CamelStoreSummary *)groupwise_store->summary, si));
@@ -1071,13 +1062,14 @@ struct _store_refresh_msg {
 	CamelException ex;
 };
 
+#if 0
 static void
 store_refresh_refresh (CamelSession *session, CamelSessionThreadMsg *msg)
 {
 	struct _store_refresh_msg *m = (struct _store_refresh_msg *)msg;
 	CamelGroupwiseStore *groupwise_store = (CamelGroupwiseStore *)m->store;
-	
-	CAMEL_SERVICE_LOCK (m->store, connect_lock);
+
+	CAMEL_SERVICE_REC_LOCK (m->store, connect_lock);
 	if (!camel_groupwise_store_connected ((CamelGroupwiseStore *)m->store, &m->ex))
 		goto done;
 	/*Get the folder list and save it here*/
@@ -1086,7 +1078,7 @@ store_refresh_refresh (CamelSession *session, CamelSessionThreadMsg *msg)
 		goto done;
 	camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 done:
-	CAMEL_SERVICE_UNLOCK (m->store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (m->store, connect_lock);
 }
 
 static void
@@ -1102,6 +1094,7 @@ static CamelSessionThreadOps store_refresh_ops = {
 	store_refresh_refresh,
 	store_refresh_free,
 };
+#endif
 
 /*** Thread stuff ends ***/
 
@@ -1112,7 +1105,7 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
 	CamelFolderInfo *info = NULL;
 	char *top_folder = NULL;
-	
+
 	if (top) {
 		top_folder = g_hash_table_lookup (priv->name_hash, top);
 		/* 'top' is a valid path, but doesnt have a container id
@@ -1124,7 +1117,7 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 		}*/
 	}
 
-	if (top && groupwise_is_system_folder (top)) 
+	if (top && groupwise_is_system_folder (top))
 		return groupwise_build_folder_info (groupwise_store, NULL, top );
 
 	/*
@@ -1132,17 +1125,17 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 	 * is used as is here.
 	 */
 	if (camel_store_summary_count ((CamelStoreSummary *)groupwise_store->summary) == 0) {
-		CAMEL_SERVICE_LOCK (store, connect_lock);
+		CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 		if (groupwise_store->list_loaded == 3) {
 			groupwise_folders_sync (groupwise_store, ex);
 			groupwise_store->list_loaded -= 1;
 		}
 		if (camel_exception_is_set (ex)) {
 			camel_store_summary_save ((CamelStoreSummary *) groupwise_store->summary);
-			CAMEL_SERVICE_UNLOCK (store, connect_lock);
+			CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 			return NULL;
 		}
-		CAMEL_SERVICE_UNLOCK (store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 		camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		goto end_r;
 	}
@@ -1153,12 +1146,12 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 		goto end_r;
 	}
 
-	CAMEL_SERVICE_LOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 	if ((groupwise_store->list_loaded == 1) && check_for_connection((CamelService *)store, ex)) {
 		if (!priv->cnc) {
 			if (groupwise_connect ((CamelService *)store, ex)) {
 				g_warning ("Could connect!!!\n");
-			} else 
+			} else
 				g_warning ("Could not connect..failure connecting\n");
 		}
 		if (camel_groupwise_store_connected ((CamelGroupwiseStore *)store, ex)) {
@@ -1166,14 +1159,14 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 				CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS (groupwise_store->current_folder))->sync(groupwise_store->current_folder, FALSE, ex);
 			groupwise_folders_sync (groupwise_store, ex);
 			if (camel_exception_is_set (ex)) {
-				CAMEL_SERVICE_UNLOCK (store, connect_lock);
+				CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 				return NULL;
 			}
 			camel_store_summary_touch ((CamelStoreSummary *)groupwise_store->summary);
 			camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		}
 	}
-	CAMEL_SERVICE_UNLOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 
 	/*camel_exception_clear (ex);*/
 end_r:
@@ -1195,23 +1188,23 @@ create_junk_folder (CamelStore *store)
 	folder_name = "Junk Mail";
 	parent_id = "";
 	/* TODO: check for offlining*/
-		
-	CAMEL_SERVICE_LOCK (store, connect_lock);
+
+	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 	status = e_gw_connection_modify_junk_settings (priv->cnc, JUNK_ENABLE, 0, 0,  JUNK_PERSISTENCE);
 	if (status == E_GW_CONNECTION_STATUS_OK) {
 		root = groupwise_build_folder_info(groupwise_store, parent_name, folder_name);
 		camel_store_summary_save((CamelStoreSummary *)groupwise_store->summary);
-		
+
 		child_container_id = e_gw_connection_get_container_id (priv->cnc, "Junk Mail");
 		if (!child_container_id)
 			g_warning("failed to retrieve id for junk folder");
-		
-		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name)); 
+
+		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name));
 		g_hash_table_insert (priv->name_hash, g_strdup(folder_name), g_strdup(child_container_id));
 		g_hash_table_insert (priv->parent_hash, g_strdup(child_container_id), g_strdup(parent_id));
 		camel_object_trigger_event (CAMEL_OBJECT (store), "folder_created", root);
 	}
-	CAMEL_SERVICE_UNLOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 
 	return root;
 }
@@ -1232,7 +1225,7 @@ groupwise_create_folder(CamelStore *store,
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot create GroupWise folders in offline mode."));
 		return NULL;
 	}
-	
+
 	if(parent_name == NULL) {
 		parent_name = "";
 		if (groupwise_is_system_folder (folder_name)) {
@@ -1256,23 +1249,23 @@ groupwise_create_folder(CamelStore *store,
 			return NULL;
 		}
 	}
-	CAMEL_SERVICE_LOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 	status = e_gw_connection_create_folder(priv->cnc,parent_id,folder_name, &child_container_id);
 	if (status == E_GW_CONNECTION_STATUS_OK) {
 		root = groupwise_build_folder_info(groupwise_store, parent_name,folder_name);
 		camel_store_summary_save((CamelStoreSummary *)groupwise_store->summary);
 
-		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name)); 
+		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name));
 		g_hash_table_insert (priv->name_hash, g_strdup(root->full_name), g_strdup(child_container_id));
 		g_hash_table_insert (priv->parent_hash, g_strdup(child_container_id), g_strdup(parent_id));
 
 		camel_object_trigger_event (CAMEL_OBJECT (store), "folder_created", root);
 	}
-	CAMEL_SERVICE_UNLOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 	return root;
 }
 
-static void 
+static void
 groupwise_delete_folder(CamelStore *store,
 				   const char *folder_name,
 				   CamelException *ex)
@@ -1280,12 +1273,12 @@ groupwise_delete_folder(CamelStore *store,
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate  *priv = groupwise_store->priv;
 	EGwConnectionStatus status;
-	const char * container; 
-	
-	CAMEL_SERVICE_LOCK (store, connect_lock);
-	
+	const char * container;
+
+	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
+
 	if (!camel_groupwise_store_connected ((CamelGroupwiseStore *)store, ex)) {
-		CAMEL_SERVICE_UNLOCK (store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 		return;
 	}
 
@@ -1301,13 +1294,13 @@ groupwise_delete_folder(CamelStore *store,
 
 		g_hash_table_remove (priv->id_hash, container);
 		g_hash_table_remove (priv->name_hash, folder_name);
-		
+
 		g_hash_table_remove (priv->parent_hash, container);
 	}
-	CAMEL_SERVICE_UNLOCK (store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 }
 
-static void 
+static void
 groupwise_rename_folder(CamelStore *store,
 		        const char *old_name,
 			const char *new_name,
@@ -1318,32 +1311,32 @@ groupwise_rename_folder(CamelStore *store,
 	char *oldpath, *newpath, *storepath;
 	const char *container_id;
 	char *temp_new = NULL;
-	
+
 	if (groupwise_is_system_folder (old_name)) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename Groupwise folder `%s' to `%s'"),
 				      old_name, new_name);
 		return;
 	}
 
-	CAMEL_SERVICE_LOCK (groupwise_store, connect_lock);
-	
+	CAMEL_SERVICE_REC_LOCK (groupwise_store, connect_lock);
+
 	if (!camel_groupwise_store_connected ((CamelGroupwiseStore *)store, ex)) {
-		CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 		return;
 	}
-	
+
 	container_id = camel_groupwise_store_container_id_lookup (groupwise_store, old_name);
 	temp_new = strrchr (new_name, '/');
-	if (temp_new) 
+	if (temp_new)
 		temp_new++;
 	else
 		temp_new = (char *)new_name;
-	
+
 	if (!container_id || e_gw_connection_rename_folder (priv->cnc, container_id , temp_new) != E_GW_CONNECTION_STATUS_OK)
 	{
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename Groupwise folder `%s' to `%s'"),
 				      old_name, new_name);
-		CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 		return;
 	}
 
@@ -1366,16 +1359,16 @@ groupwise_rename_folder(CamelStore *store,
 
 	g_free (oldpath);
 	g_free (newpath);
-	CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 }
 
-char * 
-groupwise_get_name(CamelService *service, gboolean brief) 
+char *
+groupwise_get_name(CamelService *service, gboolean brief)
 {
-	if(brief) 
+	if(brief)
 		return g_strdup_printf(_("GroupWise server %s"), service->url->host);
 	else
-		return g_strdup_printf(_("GroupWise service for %s on %s"), 
+		return g_strdup_printf(_("GroupWise service for %s on %s"),
 				       service->url->user, service->url->host);
 }
 
@@ -1426,14 +1419,14 @@ groupwise_get_trash (CamelStore *store, CamelException *ex)
 		camel_object_state_read(folder);
 
 		return folder;
-	} else 
+	} else
 		return NULL;
 }
 
 /*
  * Function to check if we are both connected and are _actually_
  * online. Based on an equivalient function in IMAP
- */ 
+ */
 gboolean
 camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex)
 {
@@ -1445,7 +1438,7 @@ camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex)
 	return FALSE;
 }
 
-static int 
+static int
 match_path(const char *path, const char *name)
 {
 	char p, n;
@@ -1479,18 +1472,18 @@ camel_groupwise_store_class_init (CamelGroupwiseStoreClass *camel_groupwise_stor
 		CAMEL_SERVICE_CLASS (camel_groupwise_store_class);
 	CamelStoreClass *camel_store_class =
 		CAMEL_STORE_CLASS (camel_groupwise_store_class);
-	
+
 	parent_class = CAMEL_OFFLINE_STORE_CLASS (camel_type_get_global_classfuncs (camel_offline_store_get_type ()));
-	
+
 	camel_service_class->construct = groupwise_store_construct;
 	camel_service_class->query_auth_types = groupwise_store_query_auth_types;
 	camel_service_class->get_name = groupwise_get_name;
 	camel_service_class->connect = groupwise_connect;
 	camel_service_class->disconnect = groupwise_disconnect;
-	
+
 	camel_store_class->hash_folder_name = groupwise_hash_folder_name;
 	camel_store_class->compare_folder_name = groupwise_compare_folder_name;
-	
+
 	camel_store_class->get_folder = groupwise_get_folder;
 	camel_store_class->create_folder = groupwise_create_folder;
 	camel_store_class->delete_folder = groupwise_delete_folder;
@@ -1507,13 +1500,13 @@ camel_groupwise_store_finalize (CamelObject *object)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (object);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
-	
+
 	g_print ("camel_groupwise_store_finalize\n");
 	if (groupwise_store->summary) {
 		camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		camel_object_unref (groupwise_store->summary);
 	}
-	
+
 	if (priv) {
 		if (priv->user) {
 			g_free (priv->user);
@@ -1535,7 +1528,7 @@ camel_groupwise_store_finalize (CamelObject *object)
 			g_free (priv->base_url);
 			priv->base_url = NULL;
 		}
-		
+
 		if (E_IS_GW_CONNECTION (priv->cnc)) {
 			g_object_unref (priv->cnc);
 			priv->cnc = NULL;
@@ -1546,7 +1539,7 @@ camel_groupwise_store_finalize (CamelObject *object)
 
 		if(groupwise_store->root_container)
 			g_free (groupwise_store->root_container);
-		
+
 		if (priv->id_hash)
 			g_hash_table_destroy (priv->id_hash);
 
@@ -1567,7 +1560,7 @@ camel_groupwise_store_init (gpointer object, gpointer klass)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (object);
 	CamelGroupwiseStorePrivate *priv = g_new0 (CamelGroupwiseStorePrivate, 1);
-	
+
 	d("in groupwise store init\n");
 	priv->server_name = NULL;
 	priv->port = NULL;
@@ -1575,14 +1568,14 @@ camel_groupwise_store_init (gpointer object, gpointer klass)
 	priv->user = NULL;
 	priv->cnc = NULL;
 	groupwise_store->priv = priv;
-	
+
 }
 
 CamelType
 camel_groupwise_store_get_type (void)
 {
 	static CamelType camel_groupwise_store_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_groupwise_store_type == CAMEL_INVALID_TYPE)	{
 		camel_groupwise_store_type =
 			camel_type_register (camel_offline_store_get_type (),
@@ -1594,6 +1587,6 @@ camel_groupwise_store_get_type (void)
 					     (CamelObjectInitFunc) camel_groupwise_store_init,
 					     (CamelObjectFinalizeFunc) camel_groupwise_store_finalize);
 	}
-	
+
 	return camel_groupwise_store_type;
 }
