@@ -1,24 +1,24 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-nntp-provider.c: nntp provider registration code */
 
-/* 
+/*
  * Authors :
  *   Chris Toshok <toshok@ximian.com>
  *
  * Copyright (C) 2000 Ximian, Inc. (www.ximian.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -27,17 +27,19 @@
 #endif
 
 #include <string.h>
+
+#include <glib/gi18n-lib.h>
+
 #include "camel-nntp-store.h"
 #include "camel-provider.h"
 #include "camel-session.h"
-#include "camel-i18n.h"
 
 static void add_hash (guint *hash, char *s);
 static guint nntp_url_hash (gconstpointer key);
 static gint check_equal (char *s1, char *s2);
 static gint nntp_url_equal (gconstpointer a, gconstpointer b);
 
-CamelProviderConfEntry nntp_conf_entries[] = {
+static CamelProviderConfEntry nntp_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "folders", NULL,
 	  N_("Folders") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "show_short_notation", NULL,
@@ -86,7 +88,8 @@ camel_provider_module_init(void)
 	news_provider.url_hash = nntp_url_hash;
 	news_provider.url_equal = nntp_url_equal;
 	news_provider.authtypes = g_list_append (NULL, &camel_nntp_password_authtype);
-	
+	news_provider.translation_domain = GETTEXT_PACKAGE;
+
 	camel_provider_register(&news_provider);
 }
 
@@ -106,7 +109,7 @@ nntp_url_hash (gconstpointer key)
 	add_hash (&hash, u->user);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
@@ -119,7 +122,7 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
 
@@ -130,7 +133,7 @@ static gint
 nntp_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-	
+
 	return check_equal(u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
 		&& check_equal (u1->host, u2->host)
